@@ -17,6 +17,6 @@
 shinyWidgetsGallery <- function() { # nocov start
   if (!requireNamespace(package = "shinydashboard"))
     message("Package 'shinydashboard' is required to run this function")
-  shiny::shinyAppDir(system.file('examples/shinyWidgets', package='shinyWidgets', mustWork=TRUE))
+  shiny::shinyAppDir(system.file("examples/shinyWidgets", package = "shinyWidgets", mustWork = TRUE))
 }
 # nocov end
