@@ -6,7 +6,7 @@ test_that("Default", {
 
   tagdrop <- dropdown(
     "Content goes here",
-    style = "unite", icon = shiny::icon("gear"), status = "danger", width = "300px",
+    style = "unite", icon = shiny::icon("cog"), status = "danger", width = "300px",
     animate = animateOptions(
       enter = animations$fading_entrances$fadeInLeftBig,
       exit = animations$fading_exits$fadeOutRightBig
@@ -20,7 +20,7 @@ test_that("inputId", {
 
   tagdrop <- dropdown(
     "Content goes here",
-    style = "default", icon = shiny::icon("gear"), status = "danger", width = "300px",
+    style = "default", icon = shiny::icon("cog"), status = "danger", width = "300px",
     inputId = "MYID"
   )
   expect_identical(tagdrop$attribs$id, "sw-drop-MYID")
